@@ -28,11 +28,11 @@
 	} else {
 		if (x@data@dim3 == 4) {
 			start <- c(col, row, x@data@level, x@data@band)
-			count <- c(ncols, nrows, x@data@level, 1)
+			count <- c(ncols, nrows, 1, 1)
 			d <- get.var.ncdf(nc, varid=zvar, start=start, count=count)
 		} else {
 			start <- c(col, row, x@data@band, x@data@level)
-			count <- c(ncols, nrows, 1, x@data@level)
+			count <- c(ncols, nrows, 1, 1)
 			d <- get.var.ncdf(nc, varid=zvar, start=start, count=count)
 		}
 	}
@@ -53,13 +53,32 @@
 	
 	
 	
-.readRowsBrickNetCDF <- function(x, row, nrows=1, col=1, ncols=(ncol(x)-col+1), layer=1, n=nlayers(x)-layer+1) {
+.readRowsBrickNetCDF <- function(x, row, nrows=1, col=1, ncols=(ncol(x)-col+1), lyrs, layer=1, n=nlayers(x)-layer+1) {
 	
-	if ( x@file@toptobottom ) { row <- x@nrows - row - nrows + 2	}
+	if ( x@file@toptobottom ) { 
+		row <- x@nrows - row - nrows + 2
+	}
 	
 	navalue <- x@file@nodatavalue
-	layer   =  min( max( round(layer), 1), nlayers(x))
-	n =  min( max( round(n), 1), nlayers(x)-layer+1 )
+	if (missing(lyrs)) {
+		layer   =  min( max( round(layer), 1), nlayers(x))
+		n =  min( max( round(n), 1), nlayers(x)-layer+1 )
+		lyrs <- layer:(layer+n-1)
+	} else {
+		lyrs <- lyrs[lyrs %in% 1:lyrs]
+		if (length(lyrs) == 0) {
+			stop("no valid layers")
+		}
+		layer <- lyrs[1]
+		n <- lyrs[length(lyrs)] - lyrs[1] + 1
+	}
+	nlyrs <- length(lyrs)
+	alyrs <- nlyrs - layer + 1
+	nrows <- min(round(nrows), x@nrows-row+1)
+	ncols <- min((x@ncols-col+1), ncols)
+	stopifnot(nrows > 0)
+	stopifnot(ncols > 0)
+
 	
 	nc <- open.ncdf(x@file@name)
 	on.exit( close.ncdf(nc) )
@@ -86,39 +105,48 @@
 	
 	if (nlayers(x) > 1) {
 		dims = dim(d)
-		v <- matrix(nrow=nrows*ncols, ncol=n)
 
 		if (length(dims) == 3) {
 			if ( x@file@toptobottom ) { 
-				for (i in 1:n) {
+				v <- matrix(nrow=nrows*ncols, ncol=n)
+				for (i in alyrs) {
 					x <- d[,,i]
 					v[,i] <- as.vector( x[, ncol(x):1] )
 				}
 			} else {
 				dim(d) = c(dims[1] * dims[2], dims[3])
+				d <- d[, alyrs, drop=FALSE]
 				d[d == x@file@nodatavalue] <- NA
 				return(d)
 			}
 		} else if (length(dims) == 2) {
 			if (nrows==1) {
-				v <- d
+				d <- d[,alyrs,drop=FALSE]
+				d[d == navalue] <- NA
+				return(d)
+				
 			} else if (n==1) {
+				v <- matrix(nrow=nrows*ncols, ncol=n)
 				if ( x@file@toptobottom ) { 
 					v[] <- as.vector(d[,ncol(d):1])
 				} else {
 					v[] <- as.vector(d)				
 				}
+				
 			} else if (ncols==1) {
 				if ( x@file@toptobottom ) { 
-					d <- d[nrow(d):1,]
+					d <- d[nrow(d):1, ]
 				}
-				v <- d
+				d <- d[ ,alyrs,drop=FALSE]
+				d[d == navalue] <- NA
+				return(d)
 			}
 		} else {
+			v <- matrix(nrow=nrows*ncols, ncol=n)
 			if ( x@file@toptobottom & nrows > 1) {
 				d <- rev(d)
 			}
-			v[] <- d
+			v[] <- d[,alyrs,drop=FALSE]
 		}
 	} else {
 		if ( x@file@toptobottom ) { 
@@ -126,17 +154,11 @@
 		} else {
 			v <- as.vector(d)
 		}
-		v = matrix(v, ncol=1)
+		v <- matrix(v, ncol=1)
+		v <- v[,alyrs,drop=FALSE]
 	}
 	
 	v[v == navalue] <- NA
 	return(v)
 }
 
-
-#f = "G:/cmip/ipcc/20c3m/atm/mo/pr/bccr_bcm2_0/run1/pr_A1_1.nc"
-#r = .rasterFromCDF(f, zvar='pr', type='RasterLayer', time=1)
-#q = .rasterReadAllCDF(r)
-
-#b = .rasterFromCDF(f, zvar='pr', type='RasterBr', time=10)
-#bd = .brickReadAllCDF(b)
