@@ -4,14 +4,18 @@
 # Licence GPL v3
 
 
-setMethod('overlay', signature(x='RasterStackBrick', y='missing'), 
+setMethod('overlay', signature(x='Raster', y='missing'), 
 function(x, y, fun, filename="", ...){ 
-	
+
+	if (nlayers(x) == 1) {
+		return(calc(x, fun=fun, filename=filename, ...))
+	}
 	
 	rasters <- list()
 	for (i in 1:nlayers(x)) {
 		rasters[i] <- raster(x, i)
 	}
+	rm(x)
 	
 	if (missing(fun)) { 
 		stop("you must supply a function 'fun'. E.g., 'fun=function(x,y){return(x+y)}'") 
