@@ -4,13 +4,21 @@
 # Licence GPL v3
 
 
+setMethod("Math2", signature(x='Extent'), 
+	function (x, digits=0) {
+		digits <- max(0, digits)
+		x@xmin <- callGeneric( x@xmin, digits)
+		x@xmax <- callGeneric( x@xmax, digits)
+		x@ymin <- callGeneric( x@ymin, digits)
+		x@ymax <- callGeneric( x@ymax, digits)
+		return(x)
+	}
+)
+
+
 roundExtent <- function(object, digits=0) {
 	digits <- max(0, digits)
-	b <- extent(object)
-	b@xmin <- round(b@xmin, digits)
-	b@xmax <- round(b@xmax, digits)
-	b@ymin <- round(b@ymin, digits)
-	b@ymax <- round(b@ymax, digits)
+	b <- round(extent(object), digits)
 	if (class(object) == 'Extent') {
 		return(b)
 	}
