@@ -7,11 +7,7 @@
 stackApply <- function(x, indices, fun, filename='', na.rm=TRUE, ...) {
 
 	nl <- nlayers(x)
-	if (nl == 1) { 
-		makemat <- TRUE
-	} else {
-		makemat <- FALSE
-	}
+	if (nl == 1) { 	makemat <- TRUE	} else { makemat <- FALSE  }
 	
 	
 	ind <- vector(length=nl)
@@ -29,6 +25,11 @@ stackApply <- function(x, indices, fun, filename='', na.rm=TRUE, ...) {
 
 	filename <- trim(filename)
 
+	fun <- .makeTextFun(fun)
+	if (class(fun) == 'character') { 
+		rowcalc <- TRUE 
+		fun <- .getRowFun(fun)
+	} else { rowcalc <- FALSE  	}
 	
 	
 	if (canProcessInMemory(out, nl+nlout)) {
@@ -36,10 +37,16 @@ stackApply <- function(x, indices, fun, filename='', na.rm=TRUE, ...) {
 		a <- getValues(x)
 		if (makemat) { a < - matrix(a, ncol=1) }
 
-		for (j in uin) {
-			k <- which(ind == j)
-			sv <- apply(a[,k,drop=FALSE], 1, fun, na.rm=na.rm)
-			v[, j] <- sv
+		if (rowcalc) {
+			for (j in uin) {
+				k <- which(ind == j)
+				v[, j] <- fun(a[ , k, drop=FALSE], na.rm=na.rm)
+			}
+		} else {
+			for (j in uin) {
+				k <- which(ind == j)
+				v[, j] <- apply(a[ , k, drop=FALSE], 1, fun, na.rm=na.rm)
+			}
 		}
 		out <- setValues(out, v)
 		if (filename != "") {
@@ -48,51 +55,34 @@ stackApply <- function(x, indices, fun, filename='', na.rm=TRUE, ...) {
 		return(out)
 	}
 	
+	if (filename == '') { filename <- rasterTmpFile() } 
 	
-	
-	if (!canProcessInMemory(out, nlout) & filename == '') {
-		filename <- rasterTmpFile()
-	} 
-	
-	if (filename == '') {
-		v <- matrix(NA, nrow=ncell(out), ncol=nlout)
-	} else {
-		out <- writeStart(out, filename=filename, ...)
-	}
-	tr <- blockSize(out, nlout)
+	out <- writeStart(out, filename=filename, ...)
+	tr <- blockSize(out, n=nl+nlout)
 	pb <- pbCreate(tr$n, type=.progress(...))
 
+	v <- matrix(nrow=tr$nrows[1] * out@ncols, ncol=nlout)
 	for (i in 1:tr$n) {
 		a <- getValues(x, row=tr$row[i], nrows=tr$nrows[i])
 		if (makemat) { a < - matrix(a, ncol=1) }
-		if (filename != "") {
-			v <- matrix(nrow=tr$nrows[i] * out@ncols, ncol=nlout)
-		} else {
-			start <- 1 + (tr$row[i]-1) * out@ncols
-			end <- start + tr$nrows[i] * out@ncols - 1
-		}
+		if (i == tr$n) { v <- matrix(nrow=tr$nrows[i] * out@ncols, ncol=nlout) }
 
-		for (j in uin) {
-			k <- which(ind == j)
-			sv <- apply(a[,k,drop=FALSE], 1, fun, na.rm=na.rm)
-			if (filename == "") {
-				v[start:end, j] <- sv
-			} else {
-				v[,j] <- sv
+		if (rowcalc) {
+			for (j in uin) {
+				k <- which(ind == j)
+				v[,j] <- fun(a[,k,drop=FALSE], na.rm=na.rm)
+			}
+		} else {
+			for (j in uin) {
+				k <- which(ind == j)
+				v[,j] <- apply(a[,k,drop=FALSE], 1, fun, na.rm=na.rm)
 			}
 		}
-		if (filename != "") {
-			out <- writeValues(out, v, tr$row[i])
-		}
+		out <- writeValues(out, v, tr$row[i])
 		pbStep(pb) 
 	}
 
-	if (filename == "") { 	
-		out <- setValues(out, v)		
-	} else {
-		out <- writeStop(out)
-	}
-
+	out <- writeStop(out)
 	pbClose(pb)
 	return(out)
 }
