@@ -8,8 +8,8 @@
 
 	v <- getValues(raster)
 	raster <- .startAsciiWriting(raster, filename, ...)
-	opsci = options('scipen')
 	if (raster@file@dtype == 'INT') {
+		on.exit(options(scipen=options('scipen')))
 		options(scipen=10)
 		v <- round(v)
 	}
@@ -18,7 +18,6 @@
 	v <- matrix(v, ncol=ncol(raster), byrow=TRUE)
 	write.table(v, raster@file@name, append = TRUE, quote = FALSE, sep = " ", eol = "\n", dec = ".", row.names = FALSE, col.names = FALSE)
 
-	options(scipen=opsci)
 	return( .stopAsciiWriting(raster) )
 		
 }
